@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
+import logging
 import smtplib
 from email.header import Header
 from email.mime.text import MIMEText
 
-from loguru import logger
-
 from notify.notification import Notification
 
+logger = logging.getLogger(__name__)
+
 
 class Email(Notification):
     """邮件消息通知"""
