@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
 import requests
-from loguru import logger
+import logging
 
 from notify.notification import Notification
 
+logger = logging.getLogger(__name__)
+
 
 class PushDeer(Notification):
     """pushdeer app 消息通知"""
